@@ -31,11 +31,12 @@ Access to other functions is by method syntax, viz:
 
 =cut
 
-# Load the fundamental PDLA packages, no imports
-# Because there are no imports, we do not need
-# the usual 'eval in the user's namespace' routine.
+package PDLA::Lite;
 
-use PDLA::Core '';
+use strict;
+use warnings;
+
+use PDLA::Core qw(pdl piddle barf null);
 use PDLA::Ops '';
 use PDLA::Primitive '';
 use PDLA::Ufunc '';
@@ -45,12 +46,11 @@ use PDLA::Bad '';
 use PDLA::Version ;  # Doesn't export anything - no need for ''
 use PDLA::Lvalue;
 
-package PDLA::Lite;
-$VERSION = $PDLA::Version::VERSION;
+our $VERSION = $PDLA::Version::VERSION;
 
-@ISA = qw( PDLA::Exporter );
+our @ISA = qw( PDLA::Exporter );
 
-@EXPORT = qw( piddle pdl null barf ); # Only stuff always exported!
+our @EXPORT = qw( piddle pdl null barf ); # Only stuff always exported!
 our %EXPORT_TAGS = (
    Func     => [@EXPORT],
 );
